@@ -1,4 +1,4 @@
-package Zonemaster::Test::DNSSEC v0.0.2;
+package Zonemaster::Test::DNSSEC v0.1.0;
 
 ###
 ### This test module implements DNSSEC tests.
@@ -241,7 +241,6 @@ sub metadata {
         ],
         dnssec10 => [
             qw(
-              INVALID_NAME_FOUND
               INVALID_NAME_RCODE
               NSEC_COVERS
               NSEC_COVERS_NOT
@@ -292,7 +291,6 @@ sub translation {
         "EXTRA_PROCESSING_OK"     => "Server at {server} sent {keys} DNSKEY records and {sigs} RRSIG records.",
         "HAS_NSEC"                => "The zone has NSEC records.",
         "HAS_NSEC3"               => "The zone has NSEC3 records.",
-        "INVALID_NAME_FOUND" => "When asked for the name {name}, which must not exist, the response was not an error.",
         "INVALID_NAME_RCODE" => "When asked for the name {name}, which must not exist, the response had RCODE {rcode}.",
         "ITERATIONS_OK"      => "The number of NSEC3 iterations is {count}, which is OK.",
         "MANY_ITERATIONS"    => "The number of NSEC3 iterations is {count}, which is on the high side.",
@@ -352,7 +350,6 @@ sub policy {
         "EXTRA_PROCESSING_OK"          => "DEBUG",
         "HAS_NSEC"                     => "INFO",
         "HAS_NSEC3"                    => "INFO",
-        "INVALID_NAME_FOUND"           => "NOTICE",
         "INVALID_NAME_RCODE"           => "NOTICE",
         "ITERATIONS_OK"                => "DEBUG",
         "MANY_ITERATIONS"              => "NOTICE",
@@ -464,8 +461,9 @@ sub dnssec02 {
             }
           );
         my $dnskey_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
-        die "No response from child nameservers" if not $dnskey_p;
-        my %dnskey = map { $_->keytag => $_ } $dnskey_p->get_records( 'DNSKEY', 'answer' );
+
+        my %dnskey;
+        %dnskey = map { $_->keytag => $_ } $dnskey_p->get_records( 'DNSKEY', 'answer' ) if $dnskey_p;
 
         if ( scalar( keys %dnskey ) == 0 ) {
             push @results,
@@ -536,19 +534,21 @@ sub dnssec03 {
     my @results;
 
     my $param_p = $zone->query_one( $zone->name, 'NSEC3PARAM', { dnssec => 1 } );
-    die "No response from child zone nameservers" if not $param_p;
-    my @nsec3params = $param_p->get_records( 'NSEC3PARAM', 'answer' );
+
+    my @nsec3params;
+    @nsec3params = $param_p->get_records( 'NSEC3PARAM', 'answer' ) if $param_p;
 
     my $dk_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
-    die "No response from child zone nameservers" if not $dk_p;
-    my @dnskey = $dk_p->get_records( 'DNSKEY', 'answer' );
+
+    my @dnskey;
+    @dnskey = $dk_p->get_records( 'DNSKEY', 'answer' ) if $dk_p;
     my $min_len = min map { $_->keysize } @dnskey;
 
     if ( @nsec3params == 0 ) {
         push @results,
           info(
             NO_NSEC3PARAM => {
-                server => $param_p->answerfrom,
+                server => ($param_p ? $param_p->answerfrom : '<no response>'),
             }
           );
     }
@@ -595,21 +595,21 @@ sub dnssec04 {
 
     my $key_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
     if ( not $key_p ) {
-        die "No response from child nameservers";
+        return;
     }
     my @keys     = $key_p->get_records( 'DNSKEY', 'answer' );
     my @key_sigs = $key_p->get_records( 'RRSIG',  'answer' );
 
     my $soa_p = $zone->query_one( $zone->name, 'SOA', { dnssec => 1 } );
     if ( not $soa_p ) {
-        die "No response from child nameservers";
+        return;
     }
     my @soas     = $soa_p->get_records( 'SOA',   'answer' );
     my @soa_sigs = $soa_p->get_records( 'RRSIG', 'answer' );
 
     foreach my $sig ( @key_sigs, @soa_sigs ) {
         my $duration = $sig->expiration - $sig->inception;
-        my $remaining = $sig->expiration - int(time());
+        my $remaining = $sig->expiration - int($key_p->timestamp);
         if ( $remaining < 0 ) {    # already expired
             push @results,
               info(
@@ -671,7 +671,7 @@ sub dnssec05 {
 
     my $key_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
     if ( not $key_p ) {
-        die "No response from child nameservers";
+        return;
     }
     my @keys = $key_p->get_records( 'DNSKEY', 'answer' );
 
@@ -783,13 +783,13 @@ sub dnssec07 {
     return if not $zone->parent;
     my $key_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
     if ( not $key_p ) {
-        die "No response from child nameservers";
+        return;
     }
     my ( $dnskey ) = $key_p->get_records( 'DNSKEY', 'answer' );
 
     my $ds_p = $zone->parent->query_one( $zone->name, 'DS', { dnssec => 1 } );
     if ( not $ds_p ) {
-        die "No response from parent nameservers";
+        return;
     }
     my ( $ds ) = $ds_p->get_records( 'DS', 'answer' );
 
@@ -839,7 +839,7 @@ sub dnssec08 {
 
     my $key_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
     if ( not $key_p ) {
-        die "No response from child servers";
+        return;
     }
     my @dnskeys = $key_p->get_records( 'DNSKEY', 'answer' );
     my @sigs    = $key_p->get_records( 'RRSIG',  'answer' );
@@ -904,13 +904,13 @@ sub dnssec09 {
 
     my $key_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
     if ( not $key_p ) {
-        die "No response from child servers for DNSKEY";
+        return;
     }
     my @dnskeys = $key_p->get_records( 'DNSKEY', 'answer' );
 
     my $soa_p = $zone->query_one( $zone->name, 'SOA', { dnssec => 1 } );
     if ( not $soa_p ) {
-        die "No response from child servers for SOA";
+        return;
     }
     my @soa  = $soa_p->get_records( 'SOA',   'answer' );
     my @sigs = $soa_p->get_records( 'RRSIG', 'answer' );
@@ -975,27 +975,17 @@ sub dnssec10 {
 
     my $key_p = $zone->query_one( $zone->name, 'DNSKEY', { dnssec => 1 } );
     if ( not $key_p ) {
-        die "No response from child servers for DNSKEY";
+        return;
     }
     my @dnskeys = $key_p->get_records( 'DNSKEY', 'answer' );
 
     my $name = $zone->name->prepend( 'xx--example' );
     my $test_p = $zone->query_one( $name, 'A', { dnssec => 1 } );
     if ( not $test_p ) {
-        die "No response from child servers for A";
+        return;
     }
 
-    if ( $test_p->rcode eq 'NOERROR' ) {
-        push @results,
-          info(
-            INVALID_NAME_FOUND => {
-                name => $name,
-            }
-          );
-        return @results;
-    }
-
-    if ( $test_p->rcode ne 'NXDOMAIN' ) {
+    if ( $test_p->rcode ne 'NXDOMAIN' and $test_p->rcode ne 'NOERROR' ) {
         push @results,
           info(
             INVALID_NAME_RCODE => {
