@@ -1,4 +1,4 @@
-package Zonemaster::Translator v0.0.5;
+package Zonemaster::Translator v0.1.0;
 
 use 5.14.2;
 use strict;
@@ -82,10 +82,12 @@ sub _system_translation {
         "CANNOT_CONTINUE"       => "Not enough data about {zone} was found to be able to run tests.",
         "CONFIG_FILE"           => "Configuration was read from {name}.",
         "DEPENDENCY_VERSION"    => "Using prerequisite module {name} version {version}.",
+        "GLOBAL_VERSION"        => "Using version {version} of the Zonemaster engine.",
         "LOGGER_CALLBACK_ERROR" => "Logger callback died with error: {exception}",
         "LOOKUP_ERROR"          => "DNS query to {ns} for {name}/{type}/{class} failed with error: {message}",
         "MODULE_ERROR"          => "Fatal error in {module}: {msg}",
         "MODULE_VERSION"        => "Using module {module} version {version}.",
+        "MODULE_END"            => "Module {module} finished running.",
         "NO_NETWORK"            => "Both IPv4 and IPv6 are disabled.",
         "POLICY_FILE"           => "Policy was read from {name}.",
         "POLICY_DISABLED"       => "The module {name} was disabled by the policy.",
